summaryrefslogtreecommitdiffstats
path: root/server/src/com/vaadin/ui/Link.java
diff options
context:
space:
mode:
authorJohannes Dahlström <johannesd@vaadin.com>2012-08-29 14:32:08 +0300
committerJohannes Dahlström <johannesd@vaadin.com>2012-08-29 14:32:08 +0300
commitfadb44821a5b686b61d7ef4667b141947e85fa67 (patch)
tree35fff00ef0c17eb3e7f6ae613b7c39f09e53f720 /server/src/com/vaadin/ui/Link.java
parent729d0af2dac293774f36882f610b8c69c2aca0dd (diff)
downloadvaadin-framework-fadb44821a5b686b61d7ef4667b141947e85fa67.tar.gz
vaadin-framework-fadb44821a5b686b61d7ef4667b141947e85fa67.zip
Rename Vaadin6Component to LegacyComponent (#9434)
Diffstat (limited to 'server/src/com/vaadin/ui/Link.java')
-rw-r--r--server/src/com/vaadin/ui/Link.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/server/src/com/vaadin/ui/Link.java b/server/src/com/vaadin/ui/Link.java
index cb6b643c33..e98b558dbe 100644
--- a/server/src/com/vaadin/ui/Link.java
+++ b/server/src/com/vaadin/ui/Link.java
@@ -21,7 +21,7 @@ import java.util.Map;
import com.vaadin.server.PaintException;
import com.vaadin.server.PaintTarget;
import com.vaadin.server.Resource;
-import com.vaadin.server.Vaadin6Component;
+import com.vaadin.server.LegacyComponent;
import com.vaadin.shared.ui.BorderStyle;
/**
@@ -31,7 +31,7 @@ import com.vaadin.shared.ui.BorderStyle;
* @since 3.0
*/
@SuppressWarnings("serial")
-public class Link extends AbstractComponent implements Vaadin6Component {
+public class Link extends AbstractComponent implements LegacyComponent {
/* Target window border type constant: No window border */
@Deprecated
@@ -246,6 +246,6 @@ public class Link extends AbstractComponent implements Vaadin6Component {
@Override
public void changeVariables(Object source, Map<String, Object> variables) {
// TODO Remove once Vaadin6Component is no longer implemented
}
}
@@ -246,6 +246,6 @@ public class Link extends AbstractComponent implements Vaadin6Component {
public void changeVariables(Object source, Map<String, Object> variables) {
- // TODO Remove once Vaadin6Component is no longer implemented
+ // TODO Remove once LegacyComponent is no longer implemented
}
}